Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: chrome/browser/prefs/pref_registry_simple.h

Issue 11741003: Remove PrefServiceSimple, replacing it with PrefService and PrefRegistrySimple. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update production interfaces based on review comments. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/prefs/pref_registry_simple.h
diff --git a/chrome/browser/prefs/pref_service_simple.h b/chrome/browser/prefs/pref_registry_simple.h
similarity index 54%
rename from chrome/browser/prefs/pref_service_simple.h
rename to chrome/browser/prefs/pref_registry_simple.h
index c37d7d048d520a3932c3f390911807b1f7829b3c..168243aac65a50bc9ef5510522c7443d0eef9b6f 100644
--- a/chrome/browser/prefs/pref_service_simple.h
+++ b/chrome/browser/prefs/pref_registry_simple.h
@@ -2,25 +2,24 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_PREFS_PREF_SERVICE_SIMPLE_H_
-#define CHROME_BROWSER_PREFS_PREF_SERVICE_SIMPLE_H_
+#ifndef CHROME_BROWSER_PREFS_PREF_REGISTRY_SIMPLE_H_
+#define CHROME_BROWSER_PREFS_PREF_REGISTRY_SIMPLE_H_
-#include "chrome/browser/prefs/pref_service.h"
+#include <string>
-// A simple PrefService implementation.
-class PrefServiceSimple : public PrefService {
+#include "chrome/browser/prefs/pref_registry.h"
+
+namespace base {
+class DictionaryValue;
+class ListValue;
+}
+
+class FilePath;
+
+// A simple implementation of PrefRegistry.
+class PrefRegistrySimple : public PrefRegistry {
public:
- // You may wish to use PrefServiceBuilder or one of its subclasses
- // for simplified construction.
- PrefServiceSimple(
- PrefNotifierImpl* pref_notifier,
- PrefValueStore* pref_value_store,
- PersistentPrefStore* user_prefs,
- DefaultPrefStore* default_store,
- base::Callback<void(PersistentPrefStore::PrefReadError)>
- read_error_callback,
- bool async);
- virtual ~PrefServiceSimple();
+ PrefRegistrySimple();
void RegisterBooleanPref(const char* path, bool default_value);
void RegisterIntegerPref(const char* path, int default_value);
@@ -36,7 +35,7 @@ class PrefServiceSimple : public PrefService {
int64 default_value);
private:
- DISALLOW_COPY_AND_ASSIGN(PrefServiceSimple);
+ DISALLOW_COPY_AND_ASSIGN(PrefRegistrySimple);
};
-#endif // CHROME_BROWSER_PREFS_PREF_SERVICE_SIMPLE_H_
+#endif // CHROME_BROWSER_PREFS_PREF_REGISTRY_SIMPLE_H_

Powered by Google App Engine
This is Rietveld 408576698